var NAVTREEINDEX16 =
{
"page_library.html":[5,9],
"page_library.html#autotoc_md45":[5,9,0],
"page_library.html#autotoc_md46":[5,9,1],
"page_library.html#autotoc_md47":[5,9,2],
"page_library.html#autotoc_md48":[5,9,3],
"page_library.html#autotoc_md49":[5,9,3,0],
"page_library.html#autotoc_md50":[5,9,3,1],
"page_library.html#autotoc_md51":[5,9,3,2],
"page_library.html#autotoc_md52":[5,9,3,3],
"page_library.html#autotoc_md53":[5,9,3,4],
"page_library.html#autotoc_md54":[5,9,3,5],
"page_library.html#autotoc_md55":[5,9,3,6],
"page_library.html#autotoc_md56":[5,9,3,7],
"page_library.html#autotoc_md57":[5,9,3,8],
"page_library.html#autotoc_md58":[5,9,3,9],
"page_library.html#autotoc_md59":[5,9,4],
"page_library.html#autotoc_md60":[5,9,4,0],
"page_library.html#autotoc_md61":[5,9,4,1],
"page_library.html#autotoc_md62":[5,9,5],
"page_library.html#autotoc_md63":[5,9,6],
"page_library.html#autotoc_md64":[5,9,7],
"page_man_pipewire_1.html":[5,14,0],
"page_man_pipewire_conf_5.html":[5,14,2],
"page_man_pipewire_pulse_1.html":[5,14,1],
"page_man_pw_cat_1.html":[5,14,3],
"page_man_pw_cli_1.html":[5,14,4],
"page_man_pw_config_1.html":[5,14,5],
"page_man_pw_dot_1.html":[5,14,6],
"page_man_pw_jack_1.html":[5,14,13],
"page_man_pw_link_1.html":[5,14,7],
"page_man_pw_metadata_1.html":[5,14,8],
"page_man_pw_mididump_1.html":[5,14,9],
"page_man_pw_mon_1.html":[5,14,10],
"page_man_pw_profiler_1.html":[5,14,11],
"page_man_pw_top_1.html":[5,14,12],
"page_midi.html":[5,7],
"page_midi.html#autotoc_md20":[5,7,0],
"page_midi.html#autotoc_md21":[5,7,0,0],
"page_midi.html#autotoc_md22":[5,7,0,1],
"page_midi.html#autotoc_md23":[5,7,0,2],
"page_midi.html#autotoc_md24":[5,7,0,3],
"page_midi.html#autotoc_md25":[5,7,0,4],
"page_midi.html#autotoc_md26":[5,7,1],
"page_midi.html#autotoc_md27":[5,7,1,0],
"page_midi.html#autotoc_md28":[5,7,1,1],
"page_midi.html#autotoc_md29":[5,7,1,2],
"page_midi.html#autotoc_md30":[5,7,2],
"page_midi.html#autotoc_md31":[5,7,2,0],
"page_midi.html#autotoc_md32":[5,7,2,1],
"page_module_access.html":[6,0],
"page_module_adapter.html":[6,1],
"page_module_avb.html":[6,2],
"page_module_client_device.html":[6,3],
"page_module_client_node.html":[6,4],
"page_module_combine_stream.html":[6,5],
"page_module_echo_cancel.html":[6,6],
"page_module_example_filter.html":[6,7],
"page_module_example_sink.html":[6,8],
"page_module_example_source.html":[6,9],
"page_module_fallback_sink.html":[6,10],
"page_module_ffado_driver.html":[6,11],
"page_module_filter_chain.html":[6,12],
"page_module_jack_tunnel.html":[6,14],
"page_module_jackdbus_detect.html":[6,13],
"page_module_link_factory.html":[6,15],
"page_module_loopback.html":[6,16],
"page_module_metadata.html":[6,17],
"page_module_netjack2_driver.html":[6,18],
"page_module_netjack2_manager.html":[6,19],
"page_module_pipe_tunnel.html":[6,20],
"page_module_portal.html":[6,21],
"page_module_profiler.html":[6,22],
"page_module_protocol_native.html":[6,23],
"page_module_protocol_pulse.html":[6,24],
"page_module_protocol_simple.html":[6,25],
"page_module_pulse_tunnel.html":[6,26],
"page_module_raop_discover.html":[6,28],
"page_module_raop_sink.html":[6,27],
"page_module_roc_sink.html":[6,29],
"page_module_roc_source.html":[6,30],
"page_module_rt.html":[6,35],
"page_module_rtp_sap.html":[6,31],
"page_module_rtp_session.html":[6,34],
"page_module_rtp_sink.html":[6,32],
"page_module_rtp_source.html":[6,33],
"page_module_session_manager.html":[6,36],
"page_module_vban_recv.html":[6,37],
"page_module_vban_send.html":[6,38],
"page_module_x11_bell.html":[6,39],
"page_module_zeroconf_discover.html":[6,40],
"page_native_protocol.html":[5,12],
"page_native_protocol.html#autotoc_md116":[5,12,0],
"page_native_protocol.html#autotoc_md117":[5,12,1],
"page_native_protocol.html#autotoc_md118":[5,12,2],
"page_native_protocol.html#autotoc_md119":[5,12,2,0],
"page_native_protocol.html#autotoc_md120":[5,12,2,0,0],
"page_native_protocol.html#autotoc_md121":[5,12,2,0,1],
"page_native_protocol.html#autotoc_md122":[5,12,2,0,2],
"page_native_protocol.html#autotoc_md123":[5,12,2,0,3],
"page_native_protocol.html#autotoc_md124":[5,12,2,0,4],
"page_native_protocol.html#autotoc_md125":[5,12,2,0,5],
"page_native_protocol.html#autotoc_md126":[5,12,2,0,6],
"page_native_protocol.html#autotoc_md127":[5,12,2,1],
"page_native_protocol.html#autotoc_md128":[5,12,2,1,0],
"page_native_protocol.html#autotoc_md129":[5,12,2,1,1],
"page_native_protocol.html#autotoc_md130":[5,12,2,1,2],
"page_native_protocol.html#autotoc_md131":[5,12,2,1,3],
"page_native_protocol.html#autotoc_md132":[5,12,2,1,4],
"page_native_protocol.html#autotoc_md133":[5,12,2,1,5],
"page_native_protocol.html#autotoc_md134":[5,12,2,1,6],
"page_native_protocol.html#autotoc_md135":[5,12,2,1,7],
"page_native_protocol.html#autotoc_md136":[5,12,2,1,8],
"page_native_protocol.html#autotoc_md137":[5,12,3],
"page_native_protocol.html#autotoc_md138":[5,12,3,0],
"page_native_protocol.html#autotoc_md139":[5,12,3,0,0],
"page_native_protocol.html#autotoc_md140":[5,12,3,0,1],
"page_native_protocol.html#autotoc_md141":[5,12,3,1],
"page_native_protocol.html#autotoc_md142":[5,12,3,1,0],
"page_native_protocol.html#autotoc_md143":[5,12,3,1,1],
"page_native_protocol.html#autotoc_md144":[5,12,4],
"page_native_protocol.html#autotoc_md145":[5,12,4,0],
"page_native_protocol.html#autotoc_md146":[5,12,4,0,0],
"page_native_protocol.html#autotoc_md147":[5,12,4,0,1],
"page_native_protocol.html#autotoc_md148":[5,12,4,0,2],
"page_native_protocol.html#autotoc_md149":[5,12,4,0,3],
"page_native_protocol.html#autotoc_md150":[5,12,4,1],
"page_native_protocol.html#autotoc_md151":[5,12,4,1,0],
"page_native_protocol.html#autotoc_md152":[5,12,4,1,1],
"page_native_protocol.html#autotoc_md153":[5,12,5],
"page_native_protocol.html#autotoc_md154":[5,12,5,0],
"page_native_protocol.html#autotoc_md155":[5,12,5,0,0],
"page_native_protocol.html#autotoc_md156":[5,12,5,0,1],
"page_native_protocol.html#autotoc_md157":[5,12,5,0,2],
"page_native_protocol.html#autotoc_md158":[5,12,5,1],
"page_native_protocol.html#autotoc_md159":[5,12,5,1,0],
"page_native_protocol.html#autotoc_md160":[5,12,5,1,1],
"page_native_protocol.html#autotoc_md161":[5,12,6],
"page_native_protocol.html#autotoc_md162":[5,12,6,0],
"page_native_protocol.html#autotoc_md163":[5,12,6,1],
"page_native_protocol.html#autotoc_md164":[5,12,6,1,0],
"page_native_protocol.html#autotoc_md165":[5,12,7],
"page_native_protocol.html#autotoc_md166":[5,12,7,0],
"page_native_protocol.html#autotoc_md167":[5,12,7,1],
"page_native_protocol.html#autotoc_md168":[5,12,7,1,0],
"page_native_protocol.html#autotoc_md169":[5,12,8],
"page_native_protocol.html#autotoc_md170":[5,12,8,0],
"page_native_protocol.html#autotoc_md171":[5,12,8,1],
"page_native_protocol.html#autotoc_md172":[5,12,8,1,0],
"page_native_protocol.html#autotoc_md173":[5,12,9],
"page_native_protocol.html#autotoc_md174":[5,12,9,0],
"page_native_protocol.html#autotoc_md175":[5,12,9,0,0],
"page_native_protocol.html#autotoc_md176":[5,12,9,0,1],
"page_native_protocol.html#autotoc_md177":[5,12,9,0,2],
"page_native_protocol.html#autotoc_md178":[5,12,9,0,3],
"page_native_protocol.html#autotoc_md179":[5,12,9,1],
"page_native_protocol.html#autotoc_md180":[5,12,9,1,0],
"page_native_protocol.html#autotoc_md181":[5,12,9,1,1],
"page_native_protocol.html#autotoc_md182":[5,12,10],
"page_native_protocol.html#autotoc_md183":[5,12,10,0],
"page_native_protocol.html#autotoc_md184":[5,12,10,0,0],
"page_native_protocol.html#autotoc_md185":[5,12,10,0,1],
"page_native_protocol.html#autotoc_md186":[5,12,10,1],
"page_native_protocol.html#autotoc_md187":[5,12,10,1,0],
"page_native_protocol.html#autotoc_md188":[5,12,10,1,1],
"page_native_protocol.html#autotoc_md189":[5,12,11],
"page_native_protocol.html#autotoc_md190":[5,12,11,0],
"page_native_protocol.html#autotoc_md191":[5,12,11,0,0],
"page_native_protocol.html#autotoc_md192":[5,12,11,0,1],
"page_native_protocol.html#autotoc_md193":[5,12,11,0,2],
"page_native_protocol.html#autotoc_md194":[5,12,11,0,3],
"page_native_protocol.html#autotoc_md195":[5,12,11,0,4],
"page_native_protocol.html#autotoc_md196":[5,12,11,0,5],
"page_native_protocol.html#autotoc_md197":[5,12,11,1],
"page_native_protocol.html#autotoc_md198":[5,12,11,1,0],
"page_native_protocol.html#autotoc_md199":[5,12,11,1,1],
"page_native_protocol.html#autotoc_md200":[5,12,11,1,2],
"page_native_protocol.html#autotoc_md201":[5,12,11,1,3],
"page_native_protocol.html#autotoc_md202":[5,12,11,1,4],
"page_native_protocol.html#autotoc_md203":[5,12,11,1,5],
"page_native_protocol.html#autotoc_md204":[5,12,11,1,6],
"page_native_protocol.html#autotoc_md205":[5,12,11,1,7],
"page_native_protocol.html#autotoc_md206":[5,12,11,1,8],
"page_native_protocol.html#autotoc_md207":[5,12,11,1,9],
"page_native_protocol.html#autotoc_md208":[5,12,11,1,10],
"page_native_protocol.html#autotoc_md209":[5,12,11,1,11],
"page_native_protocol.html#autotoc_md210":[5,12,12],
"page_native_protocol.html#autotoc_md211":[5,12,12,0],
"page_native_protocol.html#autotoc_md212":[5,12,12,0,0],
"page_native_protocol.html#autotoc_md213":[5,12,12,0,1],
"page_native_protocol.html#autotoc_md214":[5,12,12,1],
"page_native_protocol.html#autotoc_md215":[5,12,12,1,0],
"page_native_protocol.html#autotoc_md216":[5,12,13],
"page_native_protocol.html#autotoc_md217":[5,12,13,0],
"page_native_protocol.html#autotoc_md218":[5,12,13,1],
"page_native_protocol.html#autotoc_md219":[5,12,13,1,0],
"page_objects_design.html":[5,8],
"page_objects_design.html#autotoc_md68":[5,8,0],
"page_objects_design.html#autotoc_md69":[5,8,0,0],
"page_objects_design.html#autotoc_md70":[5,8,0,1],
"page_objects_design.html#autotoc_md71":[5,8,0,2],
"page_objects_design.html#autotoc_md72":[5,8,1],
"page_objects_design.html#autotoc_md73":[5,8,1,0],
"page_objects_design.html#autotoc_md74":[5,8,1,0,0],
"page_objects_design.html#autotoc_md75":[5,8,1,1],
"page_objects_design.html#autotoc_md76":[5,8,1,2],
"page_objects_design.html#autotoc_md77":[5,8,1,2,0],
"page_objects_design.html#autotoc_md78":[5,8,2],
"page_objects_design.html#autotoc_md79":[5,8,2,0],
"page_objects_design.html#autotoc_md80":[5,8,2,1],
"page_objects_design.html#autotoc_md81":[5,8,2,1,0],
"page_objects_design.html#autotoc_md82":[5,8,2,1,1],
"page_objects_design.html#autotoc_md83":[5,8,3],
"page_objects_design.html#autotoc_md84":[5,8,3,0],
"page_objects_design.html#autotoc_md85":[5,8,3,1],
"page_objects_design.html#autotoc_md86":[5,8,3,2],
"page_objects_design.html#autotoc_md87":[5,8,4],
"page_objects_design.html#autotoc_md88":[5,8,4,0],
"page_objects_design.html#autotoc_md89":[5,8,4,0,0],
"page_objects_design.html#autotoc_md90":[5,8,4,0,1],
"page_objects_design.html#autotoc_md91":[5,8,4,1],
"page_objects_design.html#autotoc_md92":[5,8,4,1,0],
"page_objects_design.html#autotoc_md93":[5,8,4,1,1],
"page_overview.html":[4],
"page_overview.html#autotoc_md4":[4,0],
"page_pipewire.html":[5],
"page_pipewire.html#autotoc_md5":[5,0],
"page_pipewire.html#autotoc_md6":[5,1],
"page_pipewire.html#autotoc_md7":[5,2],
"page_pipewire_modules.html":[6],
"page_portal.html":[5,6],
"page_portal.html#autotoc_md33":[5,6,0],
"page_portal.html#autotoc_md34":[5,6,0,0],
"page_portal.html#autotoc_md35":[5,6,0,1],
"page_portal.html#autotoc_md36":[5,6,0,2],
"page_portal.html#autotoc_md37":[5,6,1],
"page_portal.html#autotoc_md38":[5,6,1,0],
"page_portal.html#autotoc_md39":[5,6,1,1],
"page_portal.html#autotoc_md40":[5,6,1,2],
"page_portal.html#autotoc_md41":[5,6,1,3],
"page_proxy.html":[8,1],
"page_proxy.html#sec_page_proxy_bind":[8,1,3],
"page_proxy.html#sec_page_proxy_core":[8,1,1],
"page_proxy.html#sec_page_proxy_create":[8,1,2],
"page_proxy.html#sec_page_proxy_destroy":[8,1,6],
"page_proxy.html#sec_page_proxy_events":[8,1,5],
"page_proxy.html#sec_page_proxy_methods":[8,1,4],
"page_proxy.html#sec_page_proxy_overview":[8,1,0],
"page_pulseaudio.html":[5,16],
"page_pulseaudio.html#autotoc_md281":[5,16,0],
"page_pulseaudio.html#autotoc_md282":[5,16,0,0]
};
